#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location   : http://pyopenssl.sourceforge.net/
# last revised      : 24.11.2009

softname='pyOpenSSL'
softversion='0.10'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/pyopenssl/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
         |-----handy-ruler------------------------------------------------------|
pyOpenSSL: pyOpenSSL - A Python wrapper around the OpenSSL library
pyOpenSSL:
pyOpenSSL: This module is a rather thin wrapper around (a subset of) the OpenSSL
pyOpenSSL: library. With thin wrapper I mean that a lot of the object methods do
pyOpenSSL: nothing more than calling a corresponding function in the OpenSSL
pyOpenSSL: library.
pyOpenSSL: 
pyOpenSSL:
pyOpenSSL:
pyOpenSSL:
pyOpenSSL:
EOF

# check if package is present 
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
    ./setup.py install  --root=$dest --prefix=/usr

# add 'default' files
cd $src
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
    README COPYING ChangeLog INSTALL TODO\
    $dest/usr/doc/$softname-$softversion
	
# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "openssl,python" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/pyopenssl/source/build-pyOpenSSL.sh > $package.src
echo $source >> $package.src

# erase 
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
